@@ -143,3 +143,7 @@ def del_line_in_file(file_path, old_line_number):
 def read_text_file(file_path):
     from pathlib import Path
     return Path(file_path).read_text()
+
+def display_text(content):
+    from IPython.display import Code
+    return Code(data=content, language="text")
